[pypy-commit] pypy even-more-jit-hooks: one more attr

fijal noreply at buildbot.pypy.org
Sun Jul 8 14:35:19 CEST 2012


Author: Maciej Fijalkowski <fijall at gmail.com>
Branch: even-more-jit-hooks
Changeset: r55993:61fa3ace9486
Date: 2012-07-08 14:35 +0200
http://bitbucket.org/pypy/pypy/changeset/61fa3ace9486/

Log:	one more attr

diff --git a/pypy/module/pypyjit/interp_resop.py b/pypy/module/pypyjit/interp_resop.py
--- a/pypy/module/pypyjit/interp_resop.py
+++ b/pypy/module/pypyjit/interp_resop.py
@@ -293,9 +293,9 @@
                           (self.jd_name, lgt, code_repr))
 
 @unwrap_spec(loopno=int, asmaddr=int, asmlen=int, loop_no=int,
-             type=str, jd_name=str)
+             type=str, jd_name=str, bridge_no=int)
 def descr_new_jit_loop_info(space, w_subtype, w_greenkey, w_ops, loopno,
                             asmaddr, asmlen, loop_no, type, jd_name):
     w_info = space.allocate_instance(W_JitLoopInfo, w_subtype)
     w_info.w_green_key = w_greenkey
     w_info.w_ops = w_ops
@@ -304,6 +304,7 @@
     w_info.loop_no = loop_no
     w_info.type = type
     w_info.jd_name = jd_name
+    w_info.bridge_no = bridge_no
     return w_info
 
 W_JitLoopInfo.typedef = TypeDef(
@@ -293,9 +293,9 @@
 def descr_new_jit_loop_info(space, w_subtype, w_greenkey, w_ops, loopno,
-                            asmaddr, asmlen, loop_no, type, jd_name):
+                            asmaddr, asmlen, loop_no, type, jd_name, bridge_no):
     w_info = space.allocate_instance(W_JitLoopInfo, w_subtype)
     w_info.w_green_key = w_greenkey


More information about the pypy-commit mailing list